Clazz.declarePackage("J.api");
(function(){
var c$ = Clazz.declareType(J.api, "JmolAdapterStructureIterator", null);
})();
;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
